emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
* [PATCH] Fix typos surrounding `org-agenda-skip-scheduled-repeats-after-deadline'
@ 2024-05-24 13:41 Morgan Smith
  2024-05-24 17:59 ` Ihor Radchenko
  0 siblings, 1 reply; 2+ messages in thread
From: Morgan Smith @ 2024-05-24 13:41 UTC (permalink / raw)
  To: emacs-orgmode; +Cc: Morgan Smith

* etc/ORG-NEWS: Fix typos.
* testing/lisp/test-org-agenda.el: Fix typos.
---

Hello!

I was reading through the news and found this entry a little confusing.  Also
the variable names wheren't quite right.

Thanks,

Morgan

 etc/ORG-NEWS                    | 13 +++++--------
 testing/lisp/test-org-agenda.el | 26 +++++++++++++-------------
 2 files changed, 18 insertions(+), 21 deletions(-)

diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 585b2b262..e2bbe3e0e 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -666,19 +666,16 @@ arrived.
 Users who often work with altering REPL prompts may consider reducing
 the default 5 second value of the new option.
 
-*** ~repeated-after-deadline~ value of ~org-agenda-skip-scheduled-repeats-after-deadline~ is moved to a new customization
+*** ~repeated-after-deadline~ value of ~org-agenda-skip-scheduled-if-deadline-is-shown~ is moved to a new customization
 
 A new custom option ~org-agenda-skip-scheduled-repeats-after-deadline~
 is introduced in place of ~repeated-after-deadline~ value of
-~org-agenda-skip-scheduled-repeats-after-deadline~.
+~org-agenda-skip-scheduled-if-deadline-is-shown~.
 
-Introducing a new option allow more control over agenda display and
-resolves a confusion about the meaning of ~repeated-after-deadline~.
-~repeated-after-deadline~ has nothing to do with /showing/ deadline.
-It just prevents agenda display repeated scheduled entries past
-deadline. The following example illustrates the meaning:
+The following example would no longer show in the agenda as scheduled
+after January 5th with the new customization set to ~t~.
 
-: * TODO Do me every day before Jan, 12th (included)
+: * TODO Do me every day until Jan, 5th (inclusive)
 : SCHEDULED: <2024-01-03 Wed +1d> DEADLINE: <2024-01-05 Fri>
 
 The old customization will continue to work, ensuring backwards compatibility.
diff --git a/testing/lisp/test-org-agenda.el b/testing/lisp/test-org-agenda.el
index d4f7e71b4..72a005e71 100644
--- a/testing/lisp/test-org-agenda.el
+++ b/testing/lisp/test-org-agenda.el
@@ -598,7 +598,7 @@ DEADLINE: " (cdr timestamp))))
   (dolist (org-agenda-skip-scheduled-repeats-after-deadline '(nil t))
     (org-test-at-time "2024-01-01 8:00"
       (org-test-with-temp-text-in-file "
 * TODO Do me every day before Jan, 12th (included)
 SCHEDULED: <2024-01-03 Wed +1d> DEADLINE: <2024-01-05 Fri>
 "
         (let ((org-agenda-span 'week)
@@ -614,15 +614,15 @@ SCHEDULED: <2024-01-03 Wed +1d> DEADLINE: <2024-01-05 Fri>
                (string-match-p
                 "Week-agenda (W01):
 Monday      1 January 2024 W01
-  [^:]+:In   4 d.:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:In   4 d.:  TODO Do me every day until Jan, 5th (inclusive)
 Tuesday     2 January 2024
 Wednesday   3 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
 Thursday    4 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
 Friday      5 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
-  [^:]+:Deadline:   TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
+  [^:]+:Deadline:   TODO Do me every day until Jan, 5th (inclusive)
 Saturday    6 January 2024
 Sunday      7 January 2024"
                 (buffer-string)))
@@ -631,19 +631,19 @@ Sunday      7 January 2024"
              (string-match-p
               "Week-agenda (W01):
 Monday      1 January 2024 W01
-  [^:]+:In   4 d.:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:In   4 d.:  TODO Do me every day until Jan, 5th (inclusive)
 Tuesday     2 January 2024
 Wednesday   3 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
 Thursday    4 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
 Friday      5 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
-  [^:]+:Deadline:   TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
+  [^:]+:Deadline:   TODO Do me every day until Jan, 5th (inclusive)
 Saturday    6 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)
 Sunday      7 January 2024
-  [^:]+:Scheduled:  TODO Do me every day before Jan, 12th (included)"
+  [^:]+:Scheduled:  TODO Do me every day until Jan, 5th (inclusive)"
               (buffer-string))))))
       (org-test-agenda--kill-all-agendas))))
 
@@ -598,7 +598,7 @@ DEADLINE: " (cdr timestamp))))
     (org-test-at-time "2024-01-01 8:00"
       (org-test-with-temp-text-in-file "
-* TODO Do me every day before Jan, 12th (included)
+* TODO Do me every day until Jan, 5th (inclusive)
 SCHEDULED: <2024-01-03 Wed +1d> DEADLINE: <2024-01-05 Fri>
 "
-- 
2.41.0



^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [PATCH] Fix typos surrounding `org-agenda-skip-scheduled-repeats-after-deadline'
  2024-05-24 13:41 [PATCH] Fix typos surrounding `org-agenda-skip-scheduled-repeats-after-deadline' Morgan Smith
@ 2024-05-24 17:59 ` Ihor Radchenko
  0 siblings, 0 replies; 2+ messages in thread
From: Ihor Radchenko @ 2024-05-24 17:59 UTC (permalink / raw)
  To: Morgan Smith; +Cc: emacs-orgmode

Morgan Smith <Morgan.J.Smith@outlook.com> writes:

> * etc/ORG-NEWS: Fix typos.
> * testing/lisp/test-org-agenda.el: Fix typos.
> ---
>
> Hello!
>
> I was reading through the news and found this entry a little confusing.  Also
> the variable names wheren't quite right.

Thanks!
Applied, onto main.
https://git.savannah.gnu.org/cgit/emacs/org-mode.git/commit/?id=a3c1a8502

-- 
Ihor Radchenko // yantar92,
Org mode contributor,
Learn more about Org mode at <https://orgmode.org/>.
Support Org development at <https://liberapay.com/org-mode>,
or support my work at <https://liberapay.com/yantar92>


^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2024-05-24 17:58 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-05-24 13:41 [PATCH] Fix typos surrounding `org-agenda-skip-scheduled-repeats-after-deadline' Morgan Smith
2024-05-24 17:59 ` Ihor Radchenko

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).